Introduction
============

This packages contains a set of customisations of the `Euphorie
<http://packages.python.org/Euphorie/>`_ risk assessment tool as
needed for the `Dutch RI&E <http://instrumenten.rie.nl/>`_ site.

Modifications
=============

Dutch company data
------------------

The company data collected and printed during the report phase is extended
with numerous extra fields.

Old RI&E session import
-----------------------

``tno.euphorie`` extends the online client to allow importing of survey
sessions as generated by the old version of the *instrumenten.rie.nl* site
as used up to September 2010. This can be done via a new form that is
reachable from the country/session start page.


Installation
============

This package must be installed like a standard third party Plone
product:

* add the package to the python environment used by the Zope instance.
* configure Zope to load the ``tno.euphorie`` zcml
* restart Zope
* install the package via the quick installer tool in the ZMI

If you do not already have Euphorie installed it will be installed
automatically.

